==> haskell-microaeson-0.1.0.2-89-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-microaeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 microaeson
version:              0.1.0.2
visibility:           public
id:                   microaeson-0.1.0.2-KEVyQGzCEyc9tT5qYzmNLX
key:                  microaeson-0.1.0.2-KEVyQGzCEyc9tT5qYzmNLX
license:              GPL-3.0-only
maintainer:           Andreas Abel
author:               Herbert Valerio Riedel
synopsis:             A tiny JSON library with light dependency footprint
description:
    @microaeson@ aims to provide a [RFC 8259](https://tools.ietf.org/html/rfc8259) compliant JavaScript Object Notation (JSON) implementation.
    The [microaeson](https://hackage.haskell.org/package/microaeson) package provides a smaller subset of the [aeson](https://hackage.haskell.org/package/aeson) API with less dependencies and a simpler implementation.

    The API is designed in such a way to allow to easily convert client code written against @microaeson@'\''s API to use the full [aeson](https://hackage.haskell.org/package/aeson) API.

category:             Text, Web, JSON
abi:                  c228295a7c8a24c71d0050f089edf47c
exposed:              True
exposed-modules:      Data.Aeson.Micro
hidden-modules:       Data.Aeson.Micro.Parser Data.Aeson.Micro.Scanner
import-dirs:          /usr/lib/ghc-9.4.8/site-local/microaeson-0.1.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/microaeson-0.1.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/microaeson-0.1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-microaeson
hs-libraries:         HSmicroaeson-0.1.0.2-KEVyQGzCEyc9tT5qYzmNLX
depends:
    array-0.5.4.0 base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    deepseq-1.4.8.0 text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-microaeson/html/microaeson.haddock
haddock-html:         /usr/share/doc/haskell-microaeson/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-microaeson-0.1.0.2-90-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-microaeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 microaeson
version:              0.1.0.2
visibility:           public
id:                   microaeson-0.1.0.2-56kA81hOTaRABXGom4MF0b
key:                  microaeson-0.1.0.2-56kA81hOTaRABXGom4MF0b
license:              GPL-3.0-only
maintainer:           Andreas Abel
author:               Herbert Valerio Riedel
synopsis:             A tiny JSON library with light dependency footprint
description:
    @microaeson@ aims to provide a [RFC 8259](https://tools.ietf.org/html/rfc8259) compliant JavaScript Object Notation (JSON) implementation.
    The [microaeson](https://hackage.haskell.org/package/microaeson) package provides a smaller subset of the [aeson](https://hackage.haskell.org/package/aeson) API with less dependencies and a simpler implementation.

    The API is designed in such a way to allow to easily convert client code written against @microaeson@'\''s API to use the full [aeson](https://hackage.haskell.org/package/aeson) API.

category:             Text, Web, JSON
abi:                  de9cba6fbb95e13a2410a705e50951a2
exposed:              True
exposed-modules:      Data.Aeson.Micro
hidden-modules:       Data.Aeson.Micro.Parser Data.Aeson.Micro.Scanner
import-dirs:          /usr/lib/ghc-9.4.8/site-local/microaeson-0.1.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/microaeson-0.1.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/microaeson-0.1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-microaeson
hs-libraries:         HSmicroaeson-0.1.0.2-56kA81hOTaRABXGom4MF0b
depends:
    array-0.5.4.0 base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    deepseq-1.4.8.0 text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-microaeson/html/microaeson.haddock
haddock-html:         /usr/share/doc/haskell-microaeson/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
